==> ugene_1.19.0%2Bdfsg.orig.tar.xz: ugene-1.19.0/src/corelibs/U2Gui/src/util/ExportAnnotationsDialog.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2015 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_EXPORT_ANNOTATIONS_DIALOG_H_
#define _U2_EXPORT_ANNOTATIONS_DIALOG_H_

#include <U2Core/global.h>

#if (QT_VERSION < 0x050000) //Qt 5
#include <QtGui/QDialog>
#else
#include <QtWidgets/QDialog>
#endif

namespace U2 {

namespace Ui {

class ExportAnnotationsDialog;

}

class U2GUI_EXPORT ExportAnnotationsDialog : public QDialog {
    Q_OBJECT
    Q_DISABLE_COPY( ExportAnnotationsDialog )
public:
                                    ExportAnnotationsDialog( const QString &filename,
                                            QWidget *parent );
                                    ~ExportAnnotationsDialog( );

    QString                         fileFormat( ) const;
    QString                         filePath( ) const;
    bool                            exportSequence( ) const;
    bool                            exportSequenceNames( ) const;
    void                            setExportSequenceVisible( bool value );

private slots:
    void                            sl_onChooseFileButtonClicked( );
    void                            sl_onFormatChanged( const QString & );

public:
    static const QString            CSV_FORMAT_ID;

private:
    QList<QString>                  supportedFormatsExts;
    Ui::ExportAnnotationsDialog *   ui;
};

} // namespace U2

#endif // _U2_EXPORT_ANNOTATIONS_DIALOG_H_

==> ugene_1.25.0%2Bdfsg.orig.tar.xz: ugene-1.25.0/src/corelibs/U2Gui/src/util/ExportAnnotationsDialog.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_EXPORT_ANNOTATIONS_DIALOG_H_
#define _U2_EXPORT_ANNOTATIONS_DIALOG_H_

#include <QDialog>

#include <U2Core/global.h>

namespace U2 {

class Ui_ExportAnnotationsDialog;


class SaveDocumentController;

class U2GUI_EXPORT ExportAnnotationsDialog : public QDialog {
    Q_OBJECT
    Q_DISABLE_COPY( ExportAnnotationsDialog )
public:
                                    ExportAnnotationsDialog( const QString &filename,
                                            QWidget *parent );
                                    ~ExportAnnotationsDialog( );

    QString                         fileFormat( ) const;
    QString                         filePath( ) const;
    bool                            exportSequence( ) const;
    bool                            exportSequenceNames( ) const;
    void                            setExportSequenceVisible( bool value );

    static const QString            CSV_FORMAT_ID;

private slots:
    void sl_formatChanged(const QString &newFormatId);

private:
    void                            initSaveController(const QString &filename);

    QList<QString>                  supportedFormatsExts;
    SaveDocumentController *        saveController;
    Ui_ExportAnnotationsDialog *    ui;
};

} // namespace U2

#endif // _U2_EXPORT_ANNOTATIONS_DIALOG_H_
